@@ -12,7 +12,7 @@ Python libraries, though it does make heavy use of external packaging commands.
 Visit <https://github.com/datalad/datalad-installer> for more information.
 """
 
-__version__ = "0.5.0"
+__version__ = "0.5.1"
 __author__ = "The DataLad Team and Contributors"
 __author_email__ = "team@datalad.org"
 __license__ = "MIT"
@@ -867,6 +867,8 @@ class MinicondaComponent(Component):
         **kwargs: Any,
     ) -> None:
         log.info("Installing Miniconda")
+        if "CONDA_PREFIX" in os.environ:
+            raise RuntimeError("Conda already active; not installing miniconda")
         if path is None:
             path = mktempdir("dl-miniconda-")
             # The Miniconda installer requires that the given path not already
